@@ -24,8 +24,8 @@
 #include "umlentityattributelist.h"
 #include "umlclassifierlistitemlist.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QFile>
 #include <QList>
@@ -613,10 +613,9 @@ void SQLWriter::printCheckConstraints(QTextStream& sql, UMLClassifierListItemLis
         sql << "ALTER TABLE " << cleanName(m_pEntity->name())
             <<" ADD CONSTRAINT " << cleanName(chConstr->name())
             <<" CHECK (" << chConstr->getCheckCondition()
-            <<")";
+            <<");";
 
         sql << m_endl;
    }
 }
 
-#include "sqlwriter.moc"
